==> blesta-5.10.2.zip: blesta/plugins/support_manager/language/nl_nl/admin_departments.php <==
<?php
/**
 * Admin Departments
 *
 * @package blesta
 * @subpackage blesta.language.nl_nl
 * @copyright Copyright (c) 2024, Phillips Data, Inc.
 * @license http://www.blesta.com/license/ The Blesta License Agreement
 * @link http://www.blesta.com/ Blesta
 */

$lang['AdminDepartments.edit.text_add'] = 'Voeg  toe';
$lang['AdminDepartments.edit.text_delete'] = 'Verwijder';
$lang['AdminDepartments.edit.heading_default'] = 'Standaard';
$lang['AdminDepartments.edit.heading_value'] = 'Waarde';
$lang['AdminDepartments.edit.heading_name'] = 'Naam';
$lang['AdminDepartments.edit.heading_options'] = 'Opties';
$lang['AdminDepartments.edit.heading_auto_delete'] = 'Automatisch verwijderen';
$lang['AdminDepartments.edit.heading_encrypted'] = 'Gecodeerd';
$lang['AdminDepartments.edit.heading_client_add'] = 'Klant kan toevoegen';
$lang['AdminDepartments.edit.heading_step'] = 'Stap';
$lang['AdminDepartments.edit.heading_max'] = 'Max';
$lang['AdminDepartments.edit.heading_min'] = 'Min';
$lang['AdminDepartments.edit.heading_type'] = 'Type';
$lang['AdminDepartments.edit.heading_visibility'] = 'Zichtbaarheid';
$lang['AdminDepartments.edit.heading_description'] = 'Beschrijving';
$lang['AdminDepartments.edit.heading_label'] = 'Label';
$lang['AdminDepartments.edit.no_results'] = 'Er zijn geen aangepaste velden in deze afdeling.';
$lang['AdminDepartments.edit.confirm_field_remove'] = 'Weet je zeker dat je dit aangepaste veld wilt verwijderen? Alle gegevens die bij dit veld horen worden verwijderd. Als je dit veld wilt verbergen en de gegevens wilt behouden, wijzig je de Zichtbaarheid in Alleen personeel.';
$lang['AdminDepartments.edit.field_add_field'] = 'Veld toevoegen';
$lang['AdminDepartments.edit.field_addsubmit'] = 'Afdeling bewerken';
$lang['AdminDepartments.edit.field_status'] = 'Status';
$lang['AdminDepartments.edit.field_response_id'] = 'Ticket automatisch sluiten';
$lang['AdminDepartments.edit.field_reminder_ticket_priority'] = 'Herinneringen sturen naar tickets met prioriteit';
$lang['AdminDepartments.edit.field_reminder_ticket_status'] = 'Herinneringen sturen naar tickets met status';
$lang['AdminDepartments.edit.field_reminder_ticket_interval'] = 'Automatisch Ticketherinneringen versturen';
$lang['AdminDepartments.edit.field_delete_ticket_interval'] = 'Tickets automatisch verwijderen';
$lang['AdminDepartments.edit.field_close_ticket_interval'] = 'Tickets automatisch sluiten';
$lang['AdminDepartments.edit.field_port'] = 'Haven';
$lang['AdminDepartments.edit.field_pass'] = 'Pas';
$lang['AdminDepartments.edit.field_user'] = 'Gebruiker';
$lang['AdminDepartments.edit.field_host'] = 'Gastheer';
$lang['AdminDepartments.edit.field_mark_messages'] = 'Markeer berichten als';
$lang['AdminDepartments.edit.field_box_name'] = 'Naam doos';
$lang['AdminDepartments.edit.field_security'] = 'Beveiliging';
$lang['AdminDepartments.edit.field_max_attachment_size'] = 'Max. grootte bijlage';
$lang['AdminDepartments.edit.field_attachment_types'] = 'Ondersteunde typen bijlagen';
$lang['AdminDepartments.edit.field_include_attachments'] = 'Ondersteunde bijlagen opnemen in ticketberichten';
$lang['AdminDepartments.edit.field_default_priority'] = 'Standaard prioriteit';
$lang['AdminDepartments.edit.field_piping_config'] = 'Leidingconfiguratie';
$lang['AdminDepartments.edit.field_method'] = 'E-mail afhandeling';
$lang['AdminDepartments.edit.field_automatic_transition'] = 'Automatisch veranderen van ticketstatus bij adminantwoord';
$lang['AdminDepartments.edit.field_send_ticket_received'] = 'Automatisch e-mails versturen voor nieuwe tickets';
$lang['AdminDepartments.edit.field_override_from_email'] = 'Overschrijf het ingestelde van-adres in e-mailsjablonen met het e-mailadres dat is ingesteld voor deze afdeling';
$lang['AdminDepartments.edit.field_email'] = 'E-mail';
$lang['AdminDepartments.edit.field_require_captcha'] = 'Menselijke verificatie vereisen voor niet-geauthenticeerde gebruikers';
$lang['AdminDepartments.edit.field_clients_only'] = 'Alleen klanten toestaan om tickets te openen of te beantwoorden';
$lang['AdminDepartments.edit.field_description'] = 'Beschrijving';
$lang['AdminDepartments.edit.field_name'] = 'Naam';
$lang['AdminDepartments.edit.tab_custom_fields'] = 'Aangepaste velden';
$lang['AdminDepartments.edit.tab_general'] = 'Algemeen';
$lang['AdminDepartments.edit.boxtitle_adddepartment'] = 'Afdeling bewerken';
$lang['AdminDepartments.add.text_add'] = 'Voeg  toe';
$lang['AdminDepartments.add.text_delete'] = 'Verwijder';
$lang['AdminDepartments.add.heading_default'] = 'Standaard';
$lang['AdminDepartments.add.heading_value'] = 'Waarde';
$lang['AdminDepartments.add.heading_name'] = 'Naam';
$lang['AdminDepartments.add.heading_options'] = 'Opties';
$lang['AdminDepartments.add.heading_auto_delete'] = 'Automatisch verwijderen';
$lang['AdminDepartments.add.heading_encrypted'] = 'Gecodeerd';
$lang['AdminDepartments.add.heading_client_add'] = 'Klant kan toevoegen';
$lang['AdminDepartments.add.heading_step'] = 'Stap';
$lang['AdminDepartments.add.heading_max'] = 'Max';
$lang['AdminDepartments.add.heading_min'] = 'Min';
$lang['AdminDepartments.add.heading_type'] = 'Type';
$lang['AdminDepartments.add.heading_visibility'] = 'Zichtbaarheid';
$lang['AdminDepartments.add.heading_description'] = 'Beschrijving';
$lang['AdminDepartments.add.heading_label'] = 'Label';
$lang['AdminDepartments.add.field_add_field'] = 'Veld toevoegen';
$lang['AdminDepartments.add.field_addsubmit'] = 'Afdeling toevoegen';
$lang['AdminDepartments.add.field_status'] = 'Status';
$lang['AdminDepartments.add.field_response_id'] = 'Ticket automatisch sluiten';
$lang['AdminDepartments.add.field_reminder_ticket_priority'] = 'Herinneringen sturen naar tickets met prioriteit';
$lang['AdminDepartments.add.field_reminder_ticket_status'] = 'Herinneringen sturen naar tickets met status';
$lang['AdminDepartments.add.field_reminder_ticket_interval'] = 'Automatisch Ticketherinneringen versturen';
$lang['AdminDepartments.add.field_delete_ticket_interval'] = 'Tickets automatisch verwijderen';
$lang['AdminDepartments.add.field_close_ticket_interval'] = 'Tickets automatisch sluiten';
$lang['AdminDepartments.add.field_port'] = 'Haven';
$lang['AdminDepartments.add.field_pass'] = 'Pas';
$lang['AdminDepartments.add.field_user'] = 'Gebruiker';
$lang['AdminDepartments.add.field_host'] = 'Gastheer';
$lang['AdminDepartments.add.field_mark_messages'] = 'Markeer berichten als';
$lang['AdminDepartments.add.field_box_name'] = 'Naam doos';
$lang['AdminDepartments.add.field_security'] = 'Beveiliging';
$lang['AdminDepartments.add.field_max_attachment_size'] = 'Max. grootte bijlage';
$lang['AdminDepartments.add.field_attachment_types'] = 'Ondersteunde typen bijlagen';
$lang['AdminDepartments.add.field_include_attachments'] = 'Ondersteunde bijlagen opnemen in ticketberichten';
$lang['AdminDepartments.add.field_default_priority'] = 'Standaard prioriteit';
$lang['AdminDepartments.add.field_piping_config'] = 'Leidingconfiguratie';
$lang['AdminDepartments.add.field_method'] = 'Afhandeling van e-mail';
$lang['AdminDepartments.add.field_automatic_transition'] = 'Automatisch veranderen van ticketstatus bij adminantwoord';
$lang['AdminDepartments.add.field_send_ticket_received'] = 'Automatisch e-mails versturen voor nieuwe tickets';
$lang['AdminDepartments.add.field_override_from_email'] = 'Overschrijf het ingestelde van-adres in e-mailsjablonen met het e-mailadres dat is ingesteld voor deze afdeling';
$lang['AdminDepartments.add.field_email'] = 'E-mail';
$lang['AdminDepartments.add.field_require_captcha'] = 'Menselijke verificatie vereisen voor niet-geauthenticeerde gebruikers';
$lang['AdminDepartments.add.field_clients_only'] = 'Alleen klanten toestaan om tickets te openen of te beantwoorden';
$lang['AdminDepartments.add.field_description'] = 'Beschrijving';
$lang['AdminDepartments.add.field_name'] = 'Naam';
$lang['AdminDepartments.add.tab_custom_fields'] = 'Aangepaste velden';
$lang['AdminDepartments.add.tab_general'] = 'Algemeen';
$lang['AdminDepartments.add.boxtitle_adddepartment'] = 'Afdeling toevoegen';
$lang['AdminDepartments.!text.remove_response'] = 'Verwijder';
$lang['AdminDepartments.!text.no_selected_response'] = 'Geen auto-close reactie geselecteerd.';
$lang['AdminDepartments.!text.add_response'] = 'Een vooraf gedefinieerde reactie voor automatisch sluiten instellen';
$lang['AdminDepartments.!tooltip.auto_delete'] = 'Als het ticket wordt gesloten, worden de veldgegevens automatisch verwijderd. De gegevens zijn niet langer zichtbaar voor het personeel.';
$lang['AdminDepartments.!tooltip.client_add'] = 'Of de client het veld wel of niet kan verzenden, indien false kan de client het veld alleen lezen.';
$lang['AdminDepartments.!tooltip.max_attachment_size'] = 'Maximale grootte van de bijlage in MB.';
$lang['AdminDepartments.!tooltip.attachment_types'] = 'Lijst met ondersteunde extensies, gescheiden door een komma (bijv. zip,jpg,png).';
$lang['AdminDepartments.!tooltip.include_attachments'] = 'Mailservers hebben beperkingen voor de grootte van bijlagen en bestandstypen. Om het risico te verkleinen dat e-mails worden geweigerd, verzoeken we je om beperkingen op te nemen voor het type en de grootte van bijlagen. Gebruik de tag {ticket.reply_has_attachments} in ticketberichten om er zeker van te zijn dat de klant op de hoogte is van bijlagen die niet zijn toegevoegd.';
$lang['AdminDepartments.!tooltip.automatic_transition'] = 'Verandert de status in %1$s wanneer een personeelslid antwoordt.';
$lang['AdminDepartments.!tooltip.send_ticket_received'] = 'Het uitvinken van dit vakje geeft aan dat nieuwe tickets die voor deze afdeling worden aangemaakt (per e-mail of per klant) geen antwoordbericht naar de klant of het personeel sturen via respectievelijk de e-mail Ticket ontvangen of de e-mail Ticket bijgewerkt.';
$lang['AdminDepartments.!tooltip.reminder_ticket_interval'] = 'Voor alle tickets met een andere status dan %1$s wordt een herinnering gestuurd naar het andere deel als er niet is gereageerd binnen de geselecteerde tijd.';
$lang['AdminDepartments.!tooltip.delete_ticket_interval'] = 'Alle tickets met een status van %1$s worden automatisch verwijderd als ze de geselecteerde tijd in die status blijven.';
$lang['AdminDepartments.!tooltip.close_ticket_interval'] = 'Alle tickets met een status anders dan %1$s waarvan het laatste antwoord van een personeelslid is, worden automatisch gesloten als er geen antwoorden zijn binnen de geselecteerde tijd.';
$lang['AdminDepartments.!tooltip.piping_config'] = 'Stel je pipingpad in zoals weergegeven, maar zorg ervoor dat je het juiste pad naar PHP op je server gebruikt. Zorg ervoor dat pipe.php uitvoerbaar is. Het kan ook zijn dat je pipe.php moet bewerken om een hashbang op regel 1 toe te voegen die er ongeveer zo uitziet: #!/usr/bin/php';
$lang['AdminDepartments.assigned_staff.no_results'] = 'Er is geen personeel toegewezen aan deze afdeling.';
$lang['AdminDepartments.assigned_staff.heading_staff'] = 'Personeel';
$lang['AdminDepartments.assigned_staff.heading_assigned_staff'] = 'Toegewezen personeel';
$lang['AdminDepartments.index.no_results'] = 'Er zijn geen afdelingen.';
$lang['AdminDepartments.index.confirm_delete'] = 'Afdelingen waaraan tickets zijn toegewezen kunnen niet worden verwijderd totdat alle tickets opnieuw zijn toegewezen aan een andere afdeling. Weet je zeker dat je deze afdeling wilt verwijderen?';
$lang['AdminDepartments.index.option_delete'] = 'Verwijder';
$lang['AdminDepartments.index.option_edit'] = 'Bewerk';
$lang['AdminDepartments.index.heading_options'] = 'Opties';
$lang['AdminDepartments.index.heading_default_priority'] = 'Standaard prioriteit';
$lang['AdminDepartments.index.heading_assigned_staff'] = 'Toegewezen personeel';
$lang['AdminDepartments.index.heading_email'] = 'E-mail';
$lang['AdminDepartments.index.heading_description'] = 'Beschrijving';
$lang['AdminDepartments.index.heading_name'] = 'Naam';
$lang['AdminDepartments.index.boxtitle_departments'] = 'Afdelingen';
$lang['AdminDepartments.index.categorylink_adddepartment'] = 'Afdeling toevoegen';
$lang['AdminDepartments.edit.page_title'] = 'Support Manager > Afdelingen > Afdeling bewerken';
$lang['AdminDepartments.add.page_title'] = 'Support Manager > Afdelingen > Afdeling toevoegen';
$lang['AdminDepartments.index.page_title'] = 'Support Manager > Afdelingen';
$lang['AdminDepartments.!success.department_deleted'] = 'De %1$s afdeling is succesvol verwijderd.';
$lang['AdminDepartments.!success.department_updated'] = 'De %1$s afdeling is succesvol bijgewerkt.';
$lang['AdminDepartments.!success.department_created'] = 'De %1$s afdeling is succesvol aangemaakt.';

==> blesta-5.11.4.zip: blesta/plugins/support_manager/language/nl_nl/admin_departments.php <==
<?php
/**
 * Admin Departments
 *
 * @package blesta
 * @subpackage blesta.language.nl_nl
 * @copyright Copyright (c) 2025, Phillips Data, Inc.
 * @license http://www.blesta.com/license/ The Blesta License Agreement
 * @link http://www.blesta.com/ Blesta
 */

$lang['AdminDepartments.edit.text_add'] = 'Voeg  toe';
$lang['AdminDepartments.edit.text_delete'] = 'Verwijder';
$lang['AdminDepartments.edit.heading_default'] = 'Standaard';
$lang['AdminDepartments.edit.heading_value'] = 'Waarde';
$lang['AdminDepartments.edit.heading_name'] = 'Naam';
$lang['AdminDepartments.edit.heading_options'] = 'Opties';
$lang['AdminDepartments.edit.heading_auto_delete'] = 'Automatisch verwijderen';
$lang['AdminDepartments.edit.heading_encrypted'] = 'Gecodeerd';
$lang['AdminDepartments.edit.heading_client_add'] = 'Klant kan toevoegen';
$lang['AdminDepartments.edit.heading_step'] = 'Stap';
$lang['AdminDepartments.edit.heading_max'] = 'Max';
$lang['AdminDepartments.edit.heading_min'] = 'Min';
$lang['AdminDepartments.edit.heading_type'] = 'Type';
$lang['AdminDepartments.edit.heading_visibility'] = 'Zichtbaarheid';
$lang['AdminDepartments.edit.heading_description'] = 'Beschrijving';
$lang['AdminDepartments.edit.heading_label'] = 'Label';
$lang['AdminDepartments.edit.no_results'] = 'Er zijn geen aangepaste velden in deze afdeling.';
$lang['AdminDepartments.edit.confirm_field_remove'] = 'Weet je zeker dat je dit aangepaste veld wilt verwijderen? Alle gegevens die bij dit veld horen worden verwijderd. Als je dit veld wilt verbergen en de gegevens wilt behouden, wijzig je de Zichtbaarheid in Alleen personeel.';
$lang['AdminDepartments.edit.field_add_field'] = 'Veld toevoegen';
$lang['AdminDepartments.edit.field_addsubmit'] = 'Afdeling bewerken';
$lang['AdminDepartments.edit.field_status'] = 'Status';
$lang['AdminDepartments.edit.field_response_id'] = 'Ticket automatisch sluiten';
$lang['AdminDepartments.edit.field_reminder_ticket_priority'] = 'Herinneringen sturen naar tickets met prioriteit';
$lang['AdminDepartments.edit.field_reminder_ticket_status'] = 'Herinneringen sturen naar tickets met status';
$lang['AdminDepartments.edit.field_reminder_ticket_interval'] = 'Automatisch Ticketherinneringen versturen';
$lang['AdminDepartments.edit.field_delete_ticket_interval'] = 'Tickets automatisch verwijderen';
$lang['AdminDepartments.edit.field_close_ticket_interval'] = 'Tickets automatisch sluiten';
$lang['AdminDepartments.edit.field_port'] = 'Haven';
$lang['AdminDepartments.edit.field_pass'] = 'Pas';
$lang['AdminDepartments.edit.field_user'] = 'Gebruiker';
$lang['AdminDepartments.edit.field_host'] = 'Gastheer';
$lang['AdminDepartments.edit.field_mark_messages'] = 'Markeer berichten als';
$lang['AdminDepartments.edit.field_box_name'] = 'Naam doos';
$lang['AdminDepartments.edit.field_security'] = 'Beveiliging';
$lang['AdminDepartments.edit.field_max_attachment_size'] = 'Max. grootte bijlage';
$lang['AdminDepartments.edit.field_attachment_types'] = 'Ondersteunde typen bijlagen';
$lang['AdminDepartments.edit.field_include_attachments'] = 'Ondersteunde bijlagen opnemen in ticketberichten';
$lang['AdminDepartments.edit.field_default_priority'] = 'Standaard prioriteit';
$lang['AdminDepartments.edit.field_piping_config'] = 'Leidingconfiguratie';
$lang['AdminDepartments.edit.field_method'] = 'E-mail afhandeling';
$lang['AdminDepartments.edit.field_automatic_transition'] = 'Automatisch veranderen van ticketstatus bij adminantwoord';
$lang['AdminDepartments.edit.field_send_ticket_received'] = 'Automatisch e-mails versturen voor nieuwe tickets';
$lang['AdminDepartments.edit.field_override_from_email'] = 'Overschrijf het ingestelde van-adres in e-mailsjablonen met het e-mailadres dat is ingesteld voor deze afdeling';
$lang['AdminDepartments.edit.field_email'] = 'E-mail';
$lang['AdminDepartments.edit.field_require_captcha'] = 'Menselijke verificatie vereisen voor niet-geauthenticeerde gebruikers';
$lang['AdminDepartments.edit.field_clients_only'] = 'Alleen klanten toestaan om tickets te openen of te beantwoorden';
$lang['AdminDepartments.edit.field_description'] = 'Beschrijving';
$lang['AdminDepartments.edit.field_name'] = 'Naam';
$lang['AdminDepartments.edit.tab_custom_fields'] = 'Aangepaste velden';
$lang['AdminDepartments.edit.tab_general'] = 'Algemeen';
$lang['AdminDepartments.edit.boxtitle_adddepartment'] = 'Afdeling bewerken';
$lang['AdminDepartments.add.text_add'] = 'Voeg  toe';
$lang['AdminDepartments.add.text_delete'] = 'Verwijder';
$lang['AdminDepartments.add.heading_default'] = 'Standaard';
$lang['AdminDepartments.add.heading_value'] = 'Waarde';
$lang['AdminDepartments.add.heading_name'] = 'Naam';
$lang['AdminDepartments.add.heading_options'] = 'Opties';
$lang['AdminDepartments.add.heading_auto_delete'] = 'Automatisch verwijderen';
$lang['AdminDepartments.add.heading_encrypted'] = 'Gecodeerd';
$lang['AdminDepartments.add.heading_client_add'] = 'Klant kan toevoegen';
$lang['AdminDepartments.add.heading_step'] = 'Stap';
$lang['AdminDepartments.add.heading_max'] = 'Max';
$lang['AdminDepartments.add.heading_min'] = 'Min';
$lang['AdminDepartments.add.heading_type'] = 'Type';
$lang['AdminDepartments.add.heading_visibility'] = 'Zichtbaarheid';
$lang['AdminDepartments.add.heading_description'] = 'Beschrijving';
$lang['AdminDepartments.add.heading_label'] = 'Label';
$lang['AdminDepartments.add.field_add_field'] = 'Veld toevoegen';
$lang['AdminDepartments.add.field_addsubmit'] = 'Afdeling toevoegen';
$lang['AdminDepartments.add.field_status'] = 'Status';
$lang['AdminDepartments.add.field_response_id'] = 'Ticket automatisch sluiten';
$lang['AdminDepartments.add.field_reminder_ticket_priority'] = 'Herinneringen sturen naar tickets met prioriteit';
$lang['AdminDepartments.add.field_reminder_ticket_status'] = 'Herinneringen sturen naar tickets met status';
$lang['AdminDepartments.add.field_reminder_ticket_interval'] = 'Automatisch Ticketherinneringen versturen';
$lang['AdminDepartments.add.field_delete_ticket_interval'] = 'Tickets automatisch verwijderen';
$lang['AdminDepartments.add.field_close_ticket_interval'] = 'Tickets automatisch sluiten';
$lang['AdminDepartments.add.field_port'] = 'Haven';
$lang['AdminDepartments.add.field_pass'] = 'Pas';
$lang['AdminDepartments.add.field_user'] = 'Gebruiker';
$lang['AdminDepartments.add.field_host'] = 'Gastheer';
$lang['AdminDepartments.add.field_mark_messages'] = 'Markeer berichten als';
$lang['AdminDepartments.add.field_box_name'] = 'Naam doos';
$lang['AdminDepartments.add.field_security'] = 'Beveiliging';
$lang['AdminDepartments.add.field_max_attachment_size'] = 'Max. grootte bijlage';
$lang['AdminDepartments.add.field_attachment_types'] = 'Ondersteunde typen bijlagen';
$lang['AdminDepartments.add.field_include_attachments'] = 'Ondersteunde bijlagen opnemen in ticketberichten';
$lang['AdminDepartments.add.field_default_priority'] = 'Standaard prioriteit';
$lang['AdminDepartments.add.field_piping_config'] = 'Leidingconfiguratie';
$lang['AdminDepartments.add.field_method'] = 'Afhandeling van e-mail';
$lang['AdminDepartments.add.field_automatic_transition'] = 'Automatisch veranderen van ticketstatus bij adminantwoord';
$lang['AdminDepartments.add.field_send_ticket_received'] = 'Automatisch e-mails versturen voor nieuwe tickets';
$lang['AdminDepartments.add.field_override_from_email'] = 'Overschrijf het ingestelde van-adres in e-mailsjablonen met het e-mailadres dat is ingesteld voor deze afdeling';
$lang['AdminDepartments.add.field_email'] = 'E-mail';
$lang['AdminDepartments.add.field_require_captcha'] = 'Menselijke verificatie vereisen voor niet-geauthenticeerde gebruikers';
$lang['AdminDepartments.add.field_clients_only'] = 'Alleen klanten toestaan om tickets te openen of te beantwoorden';
$lang['AdminDepartments.add.field_description'] = 'Beschrijving';
$lang['AdminDepartments.add.field_name'] = 'Naam';
$lang['AdminDepartments.add.tab_custom_fields'] = 'Aangepaste velden';
$lang['AdminDepartments.add.tab_general'] = 'Algemeen';
$lang['AdminDepartments.add.boxtitle_adddepartment'] = 'Afdeling toevoegen';
$lang['AdminDepartments.!text.remove_response'] = 'Verwijder';
$lang['AdminDepartments.!text.no_selected_response'] = 'Geen auto-close reactie geselecteerd.';
$lang['AdminDepartments.!text.add_response'] = 'Een vooraf gedefinieerde reactie voor automatisch sluiten instellen';
$lang['AdminDepartments.!tooltip.auto_delete'] = 'Als het ticket wordt gesloten, worden de veldgegevens automatisch verwijderd. De gegevens zijn niet langer zichtbaar voor het personeel.';
$lang['AdminDepartments.!tooltip.client_add'] = 'Of de client het veld wel of niet kan verzenden, indien false kan de client het veld alleen lezen.';
$lang['AdminDepartments.!tooltip.max_attachment_size'] = 'Maximale grootte van de bijlage in MB.';
$lang['AdminDepartments.!tooltip.attachment_types'] = 'Lijst met ondersteunde extensies, gescheiden door een komma (bijv. zip,jpg,png).';
$lang['AdminDepartments.!tooltip.include_attachments'] = 'Mailservers hebben beperkingen voor de grootte van bijlagen en bestandstypen. Om het risico te verkleinen dat e-mails worden geweigerd, verzoeken we je om beperkingen op te nemen voor het type en de grootte van bijlagen. Gebruik de tag {ticket.reply_has_attachments} in ticketberichten om er zeker van te zijn dat de klant op de hoogte is van bijlagen die niet zijn toegevoegd.';
$lang['AdminDepartments.!tooltip.automatic_transition'] = 'Verandert de status in %1$s wanneer een personeelslid antwoordt.';
$lang['AdminDepartments.!tooltip.send_ticket_received'] = 'Het uitvinken van dit vakje geeft aan dat nieuwe tickets die voor deze afdeling worden aangemaakt (per e-mail of per klant) geen antwoordbericht naar de klant of het personeel sturen via respectievelijk de e-mail Ticket ontvangen of de e-mail Ticket bijgewerkt.';
$lang['AdminDepartments.!tooltip.reminder_ticket_interval'] = 'Voor alle tickets met een andere status dan %1$s wordt een herinnering gestuurd naar het andere deel als er niet is gereageerd binnen de geselecteerde tijd.';
$lang['AdminDepartments.!tooltip.delete_ticket_interval'] = 'Alle tickets met een status van %1$s worden automatisch verwijderd als ze de geselecteerde tijd in die status blijven.';
$lang['AdminDepartments.!tooltip.close_ticket_interval'] = 'Alle tickets met een status anders dan %1$s waarvan het laatste antwoord van een personeelslid is, worden automatisch gesloten als er geen antwoorden zijn binnen de geselecteerde tijd.';
$lang['AdminDepartments.!tooltip.piping_config'] = 'Stel je pipingpad in zoals weergegeven, maar zorg ervoor dat je het juiste pad naar PHP op je server gebruikt. Zorg ervoor dat pipe.php uitvoerbaar is. Het kan ook zijn dat je pipe.php moet bewerken om een hashbang op regel 1 toe te voegen die er ongeveer zo uitziet: #!/usr/bin/php';
$lang['AdminDepartments.assigned_staff.no_results'] = 'Er is geen personeel toegewezen aan deze afdeling.';
$lang['AdminDepartments.assigned_staff.heading_staff'] = 'Personeel';
$lang['AdminDepartments.assigned_staff.heading_assigned_staff'] = 'Toegewezen personeel';
$lang['AdminDepartments.index.no_results'] = 'Er zijn geen afdelingen.';
$lang['AdminDepartments.index.confirm_delete'] = 'Afdelingen waaraan tickets zijn toegewezen kunnen niet worden verwijderd totdat alle tickets opnieuw zijn toegewezen aan een andere afdeling. Weet je zeker dat je deze afdeling wilt verwijderen?';
$lang['AdminDepartments.index.option_delete'] = 'Verwijder';
$lang['AdminDepartments.index.option_edit'] = 'Bewerk';
$lang['AdminDepartments.index.heading_options'] = 'Opties';
$lang['AdminDepartments.index.heading_default_priority'] = 'Standaard prioriteit';
$lang['AdminDepartments.index.heading_assigned_staff'] = 'Toegewezen personeel';
$lang['AdminDepartments.index.heading_email'] = 'E-mail';
$lang['AdminDepartments.index.heading_description'] = 'Beschrijving';
$lang['AdminDepartments.index.heading_name'] = 'Naam';
$lang['AdminDepartments.index.boxtitle_departments'] = 'Afdelingen';
$lang['AdminDepartments.index.categorylink_adddepartment'] = 'Afdeling toevoegen';
$lang['AdminDepartments.edit.page_title'] = 'Support Manager > Afdelingen > Afdeling bewerken';
$lang['AdminDepartments.add.page_title'] = 'Support Manager > Afdelingen > Afdeling toevoegen';
$lang['AdminDepartments.index.page_title'] = 'Support Manager > Afdelingen';
$lang['AdminDepartments.!success.department_deleted'] = 'De %1$s afdeling is succesvol verwijderd.';
$lang['AdminDepartments.!success.department_updated'] = 'De %1$s afdeling is succesvol bijgewerkt.';
$lang['AdminDepartments.!success.department_created'] = 'De %1$s afdeling is succesvol aangemaakt.';
$lang['AdminDepartments.edit.field_priorities'] = 'Beschikbare prioriteiten';
$lang['AdminDepartments.add.field_priorities'] = 'Beschikbare prioriteiten';
$lang['AdminDepartments.edit.field_force_import'] = 'Kracht import';
$lang['AdminDepartments.add.field_force_import'] = 'Kracht import';
$lang['AdminDepartments.!success.department_imported'] = 'De %1$s afdeling is succesvol geïmporteerd.';
